@@ -64,12 +64,9 @@
 #include "CheckIntegrityEntry.h"
 #include "BtProgressInfoFile.h"
 #include "DownloadContext.h"
+#include "fmt.h"
 #ifdef ENABLE_BITTORRENT
 # include "BtRegistry.h"
-# include "PeerStorage.h"
-# include "PieceStorage.h"
-# include "BtAnnounce.h"
-# include "BtRuntime.h"
 #endif // ENABLE_BITTORRENT
 
 namespace aria2 {
@@ -89,17 +86,19 @@ volatile sig_atomic_t globalHaltRequested = 0;
 
 } // namespace global
 
-DownloadEngine::DownloadEngine(const SharedHandle<EventPoll>& eventPoll):
-  eventPoll_(eventPoll),
-  logger_(LogFactory::getInstance()),
-  haltRequested_(false),
-  noWait_(false),
-  refreshInterval_(DEFAULT_REFRESH_INTERVAL),
-  cookieStorage_(new CookieStorage()),
+DownloadEngine::DownloadEngine(const SharedHandle<EventPoll>& eventPoll)
+  : eventPoll_(eventPoll),
+    haltRequested_(false),
+    noWait_(false),
+    refreshInterval_(DEFAULT_REFRESH_INTERVAL),
+    cookieStorage_(new CookieStorage()),
 #ifdef ENABLE_BITTORRENT
-  btRegistry_(new BtRegistry()),
+    btRegistry_(new BtRegistry()),
 #endif // ENABLE_BITTORRENT
-  dnsCache_(new DNSCache())
+#ifdef HAVE_ARES_ADDR_NODE
+    asyncDNSServers_(0),
+#endif // HAVE_ARES_ADDR_NODE
+    dnsCache_(new DNSCache())
 {
   unsigned char sessionId[20];
   util::generateRandomKey(sessionId);
@@ -108,6 +107,9 @@ DownloadEngine::DownloadEngine(const SharedHandle<EventPoll>& eventPoll):
 
 DownloadEngine::~DownloadEngine() {
   cleanQueue();
+#ifdef HAVE_ARES_ADDR_NODE
+  setAsyncDNSServers(0);
+#endif // HAVE_ARES_ADDR_NODE
 }
 
 void DownloadEngine::cleanQueue() {
@@ -115,8 +117,9 @@ void DownloadEngine::cleanQueue() {
   commands_.clear();
 }
 
-static void executeCommand(std::deque<Command*>& commands,
-                           Command::STATUS statusFilter)
+namespace {
+void executeCommand(std::deque<Command*>& commands,
+                    Command::STATUS statusFilter)
 {
   size_t max = commands.size();
   for(size_t i = 0; i < max; ++i) {
@@ -136,6 +139,14 @@ static void executeCommand(std::deque<Command*>& commands,
     }
   }
 }
+} // namespace
+
+namespace {
+
+// Rounding error in millis
+const int A2_DELTA = 10;
+
+} // namespace
 
 void DownloadEngine::run()
 {
@@ -143,7 +154,8 @@ void DownloadEngine::run()
   cp.reset(0);
   while(!commands_.empty() || !routineCommands_.empty()) {
     global::wallclock.reset();
-    if(cp.differenceInMillis(global::wallclock) >= refreshInterval_) {
+    calculateStatistics();
+    if(cp.differenceInMillis(global::wallclock) >= refreshInterval_-A2_DELTA) {
       refreshInterval_ = DEFAULT_REFRESH_INTERVAL;
       cp = global::wallclock;
       executeCommand(commands_, Command::STATUS_ALL);
@@ -156,7 +168,6 @@ void DownloadEngine::run()
       waitData();
     }
     noWait_ = false;
-    calculateStatistics();
   }
   onEndOfRun();
 }
@@ -167,8 +178,8 @@ void DownloadEngine::waitData()
   if(noWait_) {
     tv.tv_sec = tv.tv_usec = 0;
   } else {
-    tv.tv_sec = 1;
-    tv.tv_usec = 0;
+    tv.tv_sec = 0;
+    tv.tv_usec = refreshInterval_*1000;
   }
   eventPoll_->poll(tv);
 }
@@ -203,14 +214,14 @@ bool DownloadEngine::deleteSocketForWriteCheck(const SocketHandle& socket,
 
 void DownloadEngine::calculateStatistics()
 {
-  if(!statCalc_.isNull()) {
+  if(statCalc_) {
     statCalc_->calculateStat(this);
   }
 }
 
 void DownloadEngine::onEndOfRun()
 {
-  requestGroupMan_->updateServerStat();
+  requestGroupMan_->removeStoppedGroup(this);
   requestGroupMan_->closeFile();
   requestGroupMan_->save();
 }
@@ -219,14 +230,14 @@ void DownloadEngine::afterEachIteration()
 {
   requestGroupMan_->calculateStat();
   if(global::globalHaltRequested == 1) {
-    logger_->notice(_("Shutdown sequence commencing..."
-                      " Press Ctrl-C again for emergency shutdown."));
+    A2_LOG_NOTICE(_("Shutdown sequence commencing..."
+                    " Press Ctrl-C again for emergency shutdown."));
     requestHalt();
     global::globalHaltRequested = 2;
     setNoWait(true);
     setRefreshInterval(0);
   } else if(global::globalHaltRequested == 3) {
-    logger_->notice(_("Emergency shutdown sequence commencing..."));
+    A2_LOG_NOTICE(_("Emergency shutdown sequence commencing..."));
     requestForceHalt();
     global::globalHaltRequested = 4;
     setNoWait(true);
@@ -278,15 +289,13 @@ void DownloadEngine::addRoutineCommand(Command* command)
 void DownloadEngine::poolSocket(const std::string& key,
                                 const SocketPoolEntry& entry)
 {
-  logger_->info("Pool socket for %s", key.c_str());
+  A2_LOG_INFO(fmt("Pool socket for %s", key.c_str()));
   std::multimap<std::string, SocketPoolEntry>::value_type p(key, entry);
   socketPool_.insert(p);
 
   if(lastSocketPoolScan_.difference(global::wallclock) >= 60) {
     std::multimap<std::string, SocketPoolEntry> newPool;
-    if(logger_->debug()) {
-      logger_->debug("Scaning SocketPool and erasing timed out entry.");
-    }
+    A2_LOG_DEBUG("Scaning SocketPool and erasing timed out entry.");
     lastSocketPoolScan_ = global::wallclock;
     for(std::multimap<std::string, SocketPoolEntry>::iterator i =
           socketPool_.begin(), eoi = socketPool_.end(); i != eoi; ++i) {
@@ -294,16 +303,15 @@ void DownloadEngine::poolSocket(const std::string& key,
         newPool.insert(*i);
       }
     }
-    if(logger_->debug()) {
-      logger_->debug
-        ("%lu entries removed.",
-         static_cast<unsigned long>(socketPool_.size()-newPool.size()));
-    }
+    A2_LOG_DEBUG(fmt("%lu entries removed.",
+                     static_cast<unsigned long>
+                     (socketPool_.size()-newPool.size())));
     socketPool_ = newPool;
   }
 }
 
-static std::string createSockPoolKey
+namespace {
+std::string createSockPoolKey
 (const std::string& host, uint16_t port,
  const std::string& username,
  const std::string& proxyhost, uint16_t proxyport)
@@ -324,6 +332,7 @@ static std::string createSockPoolKey
   }
   return key;
 }
+} // namespace
 
 void DownloadEngine::poolSocket
 (const std::string& ipaddr,
@@ -356,7 +365,7 @@ void DownloadEngine::poolSocket(const SharedHandle<Request>& request,
                                 const SharedHandle<SocketCore>& socket,
                                 time_t timeout)
 {
-  if(proxyRequest.isNull()) {
+  if(!proxyRequest) {
     std::pair<std::string, uint16_t> peerInfo;
     socket->getPeerInfo(peerInfo);
     poolSocket(peerInfo.first, peerInfo.second,
@@ -377,7 +386,7 @@ void DownloadEngine::poolSocket
  const std::map<std::string, std::string>& options,                             
  time_t timeout)
 {
-  if(proxyRequest.isNull()) {
+  if(!proxyRequest) {
     std::pair<std::string, uint16_t> peerInfo;
     socket->getPeerInfo(peerInfo);
     poolSocket(peerInfo.first, peerInfo.second, username,
@@ -402,7 +411,7 @@ DownloadEngine::findSocketPoolEntry(const std::string& key)
     // We assume that if socket is readable it means peer shutdowns
     // connection and the socket will receive EOF. So skip it.
     if(!e.isTimeout() && !e.getSocket()->isReadable(0)) {
-      logger_->info("Found socket for %s", key.c_str());
+      A2_LOG_INFO(fmt("Found socket for %s", key.c_str()));
       return i;
     }
   }
@@ -452,7 +461,7 @@ DownloadEngine::popPooledSocket
   for(std::vector<std::string>::const_iterator i = ipaddrs.begin(),
         eoi = ipaddrs.end(); i != eoi; ++i) {
     s = popPooledSocket(*i, port, A2STR::NIL, 0);
-    if(!s.isNull()) {
+    if(s) {
       break;
     }
   }
@@ -469,7 +478,7 @@ DownloadEngine::popPooledSocket
   for(std::vector<std::string>::const_iterator i = ipaddrs.begin(),
         eoi = ipaddrs.end(); i != eoi; ++i) {
     s = popPooledSocket(options, *i, port, username, A2STR::NIL, 0);
-    if(!s.isNull()) {
+    if(s) {
       break;
     }
   }
@@ -533,7 +542,48 @@ void DownloadEngine::setAuthConfigFactory
 
 void DownloadEngine::setRefreshInterval(int64_t interval)
 {
-  refreshInterval_ = interval;
+  refreshInterval_ = std::min(static_cast<int64_t>(999), interval);
 }
 
+void DownloadEngine::addCommand(const std::vector<Command*>& commands)
+{
+  commands_.insert(commands_.end(), commands.begin(), commands.end());
+}
+
+void DownloadEngine::addCommand(Command* command)
+{
+  commands_.push_back(command);
+}
+
+void DownloadEngine::setRequestGroupMan
+(const SharedHandle<RequestGroupMan>& rgman)
+{
+  requestGroupMan_ = rgman;
+}
+
+void DownloadEngine::setFileAllocationMan
+(const SharedHandle<FileAllocationMan>& faman)
+{
+  fileAllocationMan_ = faman;
+}
+
+void DownloadEngine::setCheckIntegrityMan
+(const SharedHandle<CheckIntegrityMan>& ciman)
+{
+  checkIntegrityMan_ = ciman;
+}
+
+#ifdef HAVE_ARES_ADDR_NODE
+void DownloadEngine::setAsyncDNSServers(ares_addr_node* asyncDNSServers)
+{
+  ares_addr_node* node = asyncDNSServers_;
+  while(node) {
+    ares_addr_node* next = node->next;
+    delete node;
+    node = next;
+  }
+  asyncDNSServers_ = asyncDNSServers;
+}
+#endif // HAVE_ARES_ADDR_NODE
+
 } // namespace aria2
