@@ -39,38 +39,41 @@
 
 #include "util.h"
 #include "URISelector.h"
+#include "Logger.h"
 #include "LogFactory.h"
 #include "wallclock.h"
 #include "a2algo.h"
 #include "uri.h"
+#include "PeerStat.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-FileEntry::FileEntry(const std::string& path,
-                     uint64_t length,
-                     off_t offset,
-                     const std::vector<std::string>& uris):
-  path_(path), uris_(uris.begin(), uris.end()), length_(length),
-  offset_(offset),
-  requested_(true),
-  uniqueProtocol_(false),
-  maxConnectionPerServer_(1),
-  lastFasterReplace_(0),
-  logger_(LogFactory::getInstance()) {}
+FileEntry::FileEntry
+(const std::string& path,
+ uint64_t length,
+ off_t offset,
+ const std::vector<std::string>& uris)
+  : path_(path),
+    uris_(uris.begin(), uris.end()),
+    length_(length),
+    offset_(offset),
+    requested_(true),
+    uniqueProtocol_(false),
+    maxConnectionPerServer_(1),
+    lastFasterReplace_(0)
+{}
 
-FileEntry::FileEntry():
-  length_(0), offset_(0), requested_(false),
-  uniqueProtocol_(false),
-  maxConnectionPerServer_(1),
-  logger_(LogFactory::getInstance()) {}
+FileEntry::FileEntry()
+ : length_(0),
+   offset_(0),
+   requested_(false),
+   uniqueProtocol_(false),
+   maxConnectionPerServer_(1)
+{}
 
 FileEntry::~FileEntry() {}
 
-void FileEntry::setupDir()
-{
-  util::mkdirs(File(path_).getDirname());
-}
-
 FileEntry& FileEntry::operator=(const FileEntry& entry)
 {
   if(this != &entry) {
@@ -160,20 +163,32 @@ FileEntry::getRequest
         }
       }
       uris_.insert(uris_.begin(), pending.begin(), pending.end());
-      if(g == 0 && uriReuse && req.isNull() && uris_.size() == pending.size()) {
+      if(g == 0 && uriReuse && !req && uris_.size() == pending.size()) {
         // Reuse URIs other than ones in pending
         reuseUri(ignoreHost);
       } else {
         break;
       }
     }
-  } else {    
-    req = requestPool_.front();
-    requestPool_.pop_front();
-    inFlightRequests_.push_back(req);
-    if(logger_->debug()) {
-      logger_->debug("Picked up from pool: %s", req->getUri().c_str());
+  } else {
+    // Skip Request object if it is still
+    // sleeping(Request::getWakeTime() < global::wallclock).  If all
+    // pooled objects are sleeping, return first one.  Caller should
+    // inspect returned object's getWakeTime().
+    std::deque<SharedHandle<Request> >::iterator i = requestPool_.begin();
+    std::deque<SharedHandle<Request> >::iterator eoi = requestPool_.end();
+    for(; i != eoi; ++i) {
+      if((*i)->getWakeTime() <= global::wallclock) {
+        break;
+      }
     }
+    if(i == eoi) {
+      i = requestPool_.begin();
+    }
+    req = *i;
+    requestPool_.erase(i);
+    inFlightRequests_.push_back(req);
+    A2_LOG_DEBUG(fmt("Picked up from pool: %s", req->getUri().c_str()));
   }
   return req;
 }
@@ -187,12 +202,12 @@ FileEntry::findFasterRequest(const SharedHandle<Request>& base)
     return SharedHandle<Request>();
   }
   const SharedHandle<PeerStat>& fastest = requestPool_.front()->getPeerStat();
-  if(fastest.isNull()) {
+  if(!fastest) {
     return SharedHandle<Request>();
   }
   const SharedHandle<PeerStat>& basestat = base->getPeerStat();
   // TODO hard coded value. See PREF_STARTUP_IDLE_TIME
-  if(basestat.isNull() ||
+  if(!basestat ||
      (basestat->getDownloadStartTime().
       difference(global::wallclock) >= startupIdleTime &&
       fastest->getAvgDownloadSpeed()*0.8 > basestat->calculateDownloadSpeed())){
@@ -212,10 +227,10 @@ public:
   bool operator()(const SharedHandle<Request>& lhs,
                   const SharedHandle<Request>& rhs) const
   {
-    if(lhs->getPeerStat().isNull()) {
+    if(!lhs->getPeerStat()) {
       return false;
     }
-    if(rhs->getPeerStat().isNull()) {
+    if(!rhs->getPeerStat()) {
       return true;
     }
     return
@@ -227,7 +242,7 @@ public:
 void FileEntry::storePool(const SharedHandle<Request>& request)
 {
   const SharedHandle<PeerStat>& peerStat = request->getPeerStat();
-  if(!peerStat.isNull()) {
+  if(peerStat) {
     // We need to calculate average download speed here in order to
     // store Request in the right position in the pool.
     peerStat->calculateAvgDownloadSpeed();
@@ -272,11 +287,9 @@ void FileEntry::removeURIWhoseHostnameIs(const std::string& hostname)
       newURIs.push_back(*itr);
     }
   }
-  if(logger_->debug()) {
-    logger_->debug("Removed %lu duplicate hostname URIs for path=%s",
+  A2_LOG_DEBUG(fmt("Removed %lu duplicate hostname URIs for path=%s",
                    static_cast<unsigned long>(uris_.size()-newURIs.size()),
-                   getPath().c_str());
-  }
+                   getPath().c_str()));
   uris_.swap(newURIs);
 }
 
@@ -285,7 +298,7 @@ void FileEntry::removeIdenticalURI(const std::string& uri)
   uris_.erase(std::remove(uris_.begin(), uris_.end(), uri), uris_.end());
 }
 
-void FileEntry::addURIResult(std::string uri, downloadresultcode::RESULT result)
+void FileEntry::addURIResult(std::string uri, error_code::Value result)
 {
   uriResults_.push_back(URIResult(uri, result));
 }
@@ -293,9 +306,9 @@ void FileEntry::addURIResult(std::string uri, downloadresultcode::RESULT result)
 namespace {
 class FindURIResultByResult {
 private:
-  downloadresultcode::RESULT r_;
+  error_code::Value r_;
 public:
-  FindURIResultByResult(downloadresultcode::RESULT r):r_(r) {}
+  FindURIResultByResult(error_code::Value r):r_(r) {}
 
   bool operator()(const URIResult& uriResult) const
   {
@@ -305,7 +318,7 @@ public:
 } // namespace
 
 void FileEntry::extractURIResult
-(std::deque<URIResult>& res, downloadresultcode::RESULT r)
+(std::deque<URIResult>& res, error_code::Value r)
 {
   std::deque<URIResult>::iterator i =
     std::stable_partition(uriResults_.begin(), uriResults_.end(),
@@ -316,10 +329,10 @@ void FileEntry::extractURIResult
 
 void FileEntry::reuseUri(const std::vector<std::string>& ignore)
 {
-  if(logger_->debug()) {
+  if(A2_LOG_DEBUG_ENABLED) {
     for(std::vector<std::string>::const_iterator i = ignore.begin(),
           eoi = ignore.end(); i != eoi; ++i) {
-      logger_->debug("ignore host=%s", (*i).c_str());
+      A2_LOG_DEBUG(fmt("ignore host=%s", (*i).c_str()));
     }
   }
   std::deque<std::string> uris = spentUris_;
@@ -332,10 +345,10 @@ void FileEntry::reuseUri(const std::vector<std::string>& ignore)
   std::sort(errorUris.begin(), errorUris.end());
   errorUris.erase(std::unique(errorUris.begin(), errorUris.end()),
                   errorUris.end());
-  if(logger_->debug()) {
+  if(A2_LOG_DEBUG_ENABLED) {
     for(std::vector<std::string>::const_iterator i = errorUris.begin(),
           eoi = errorUris.end(); i != eoi; ++i) {
-      logger_->debug("error URI=%s", (*i).c_str());
+      A2_LOG_DEBUG(fmt("error URI=%s", (*i).c_str()));
     }
   }
   std::vector<std::string> reusableURIs;
@@ -356,11 +369,12 @@ void FileEntry::reuseUri(const std::vector<std::string>& ignore)
   }
   reusableURIs.erase(insertionPoint, reusableURIs.end());
   size_t ininum = reusableURIs.size();
-  if(logger_->debug()) {
-    logger_->debug("Found %u reusable URIs", static_cast<unsigned int>(ininum));
+  if(A2_LOG_DEBUG_ENABLED) {
+    A2_LOG_DEBUG(fmt("Found %u reusable URIs",
+                     static_cast<unsigned int>(ininum)));
     for(std::vector<std::string>::const_iterator i = reusableURIs.begin(),
           eoi = reusableURIs.end(); i != eoi; ++i) {
-      logger_->debug("URI=%s", (*i).c_str());
+      A2_LOG_DEBUG(fmt("URI=%s", (*i).c_str()));
     }
   }
   uris_.insert(uris_.end(), reusableURIs.begin(), reusableURIs.end());
@@ -458,4 +472,34 @@ bool FileEntry::insertUri(const std::string& uri, size_t pos)
   }
 }
 
+void FileEntry::setPath(const std::string& path)
+{
+  path_ = path;
+}
+
+void FileEntry::setContentType(const std::string& contentType)
+{
+  contentType_ = contentType;
+}
+
+size_t FileEntry::countInFlightRequest() const
+{
+  return inFlightRequests_.size();
+}
+
+size_t FileEntry::countPooledRequest() const
+{
+  return requestPool_.size();
+}
+
+void FileEntry::setOriginalName(const std::string& originalName)
+{
+  originalName_ = originalName;
+}
+
+bool FileEntry::emptyRequestUri() const
+{
+  return uris_.empty() && inFlightRequests_.empty() && requestPool_.empty();
+}
+
 } // namespace aria2
