@@ -36,6 +36,7 @@
 
 #include <signal.h>
 
+#include <cstring>
 #include <ostream>
 
 #include "RequestGroupMan.h"
@@ -57,8 +58,8 @@
 #include "SessionSerializer.h"
 #include "TimeA2.h"
 #include "fmt.h"
+#include "SocketCore.h"
 #ifdef ENABLE_SSL
-# include "SocketCore.h"
 # include "TLSContext.h"
 #endif // ENABLE_SSL
 
@@ -90,6 +91,53 @@ void handler(int signal) {
 }
 } // namespace
 
+#ifdef HAVE_ARES_ADDR_NODE
+
+namespace {
+
+ares_addr_node* parseAsyncDNSServers(const std::string& serversOpt)
+{
+  std::vector<std::string> servers;
+  util::split(serversOpt,
+              std::back_inserter(servers),
+              A2STR::COMMA_C,
+              true /* doStrip */);
+  ares_addr_node root;
+  root.next = 0;
+  ares_addr_node* tail = &root;
+  for(std::vector<std::string>::const_iterator i = servers.begin(),
+        eoi = servers.end(); i != eoi; ++i) {
+    struct addrinfo* res;
+    int s = callGetaddrinfo(&res, (*i).c_str(), 0, AF_UNSPEC,
+                            0, AI_NUMERICHOST, 0);
+    if(s != 0) {
+      continue;
+    }
+    WSAAPI_AUTO_DELETE<struct addrinfo*> resDeleter(res, freeaddrinfo);
+    if(res) {
+      ares_addr_node* node = new ares_addr_node();
+      node->next = 0;
+      node->family = res->ai_family;
+      if(node->family == AF_INET) {
+        struct sockaddr_in* in =
+          reinterpret_cast<struct sockaddr_in*>(res->ai_addr);
+        memcpy(&node->addr.addr4, &(in->sin_addr), 4);
+      } else {
+        struct sockaddr_in6* in =
+          reinterpret_cast<struct sockaddr_in6*>(res->ai_addr);
+        memcpy(&node->addr.addr6, &(in->sin6_addr), 16);
+      }
+      tail->next = node;
+      tail = node;
+    }
+  }
+  return root.next;
+}
+
+} // namespace
+
+#endif // HAVE_ARES_ADDR_NODE
+
 MultiUrlRequestInfo::MultiUrlRequestInfo
 (const std::vector<SharedHandle<RequestGroup> >& requestGroups,
  const SharedHandle<Option>& op,
@@ -134,7 +182,12 @@ error_code::Value MultiUrlRequestInfo::execute()
     SharedHandle<AuthConfigFactory> authConfigFactory(new AuthConfigFactory());
     File netrccf(option_->get(PREF_NETRC_PATH));
     if(!option_->getAsBool(PREF_NO_NETRC) && netrccf.isFile()) {
+#ifdef __MINGW32__
+      // Windows OS does not have permission, so set it to 0.
+      mode_t mode  = 0;
+#else // !__MINGW32__
       mode_t mode = netrccf.mode();
+#endif // !__MINGW32__
       if(mode&(S_IRWXG|S_IRWXO)) {
         A2_LOG_NOTICE(fmt(MSG_INCORRECT_NETRC_PERMISSION,
                           option_->get(PREF_NETRC_PATH).c_str()));
@@ -165,6 +218,11 @@ error_code::Value MultiUrlRequestInfo::execute()
     }
     SocketCore::setTLSContext(tlsContext);
 #endif
+#ifdef HAVE_ARES_ADDR_NODE
+    ares_addr_node* asyncDNSServers =
+      parseAsyncDNSServers(option_->get(PREF_ASYNC_DNS_SERVER));
+    e->setAsyncDNSServers(asyncDNSServers);
+#endif // HAVE_ARES_ADDR_NODE
     if(!Timer::monotonicClock()) {
       A2_LOG_WARN("Don't change system time while aria2c is running."
                   " Doing this may make aria2c hang for long time.");
