@@ -89,6 +89,16 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
+#if defined HAVE_ARES_SET_SERVERS && HAVE_ARES_ADDR_NODE
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+                                   (PREF_ASYNC_DNS_SERVER,
+                                    TEXT_ASYNC_DNS_SERVER,
+                                    NO_DEFAULT_VALUE));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
+#endif // HAVE_ARES_SET_SERVERS && HAVE_ARES_ADDR_NODE
 #endif // ENABLE_ASYNC_DNS
   {
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
@@ -218,17 +228,28 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     handlers.push_back(op);
   }
 #endif // ENABLE_DIRECT_IO
-#ifdef ENABLE_XML_RPC
   {
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
-                                   (PREF_ENABLE_XML_RPC,
-                                    TEXT_ENABLE_XML_RPC,
+                                   (PREF_ENABLE_RPC,
+                                    TEXT_ENABLE_RPC,
                                     A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
-    op->addTag(TAG_XML_RPC);
+    op->addTag(TAG_RPC);
+    handlers.push_back(op);
+  }
+  {
+    // TODO Deprecated
+    SharedHandle<OptionHandler> op
+      (new DeprecatedOptionHandler
+       (SharedHandle<OptionHandler>(new BooleanOptionHandler
+                                    (PREF_ENABLE_XML_RPC,
+                                     TEXT_ENABLE_XML_RPC,
+                                     NO_DEFAULT_VALUE,
+                                     OptionHandler::OPT_ARG)),
+        PREF_ENABLE_RPC));
+    op->addTag(TAG_RPC);
     handlers.push_back(op);
   }
-#endif // ENABLE_XML_RPC
   {
     std::string params[] = {
 #ifdef HAVE_EPOLL
@@ -558,49 +579,108 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
-#ifdef ENABLE_XML_RPC
   {
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
-                                   (PREF_XML_RPC_LISTEN_ALL,
-                                    TEXT_XML_RPC_LISTEN_ALL,
+                                   (PREF_RPC_LISTEN_ALL,
+                                    TEXT_RPC_LISTEN_ALL,
                                     A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
-    op->addTag(TAG_XML_RPC);
+    op->addTag(TAG_RPC);
     handlers.push_back(op);
   }
   {
     SharedHandle<OptionHandler> op(new NumberOptionHandler
-                                   (PREF_XML_RPC_LISTEN_PORT,
-                                    TEXT_XML_RPC_LISTEN_PORT,
+                                   (PREF_RPC_LISTEN_PORT,
+                                    TEXT_RPC_LISTEN_PORT,
                                     "6800",
                                     1024, UINT16_MAX));
-    op->addTag(TAG_XML_RPC);
+    op->addTag(TAG_RPC);
     handlers.push_back(op);
   }
   {
     SharedHandle<OptionHandler> op(new UnitNumberOptionHandler
-                                   (PREF_XML_RPC_MAX_REQUEST_SIZE,
-                                    TEXT_XML_RPC_MAX_REQUEST_SIZE,
+                                   (PREF_RPC_MAX_REQUEST_SIZE,
+                                    TEXT_RPC_MAX_REQUEST_SIZE,
                                     "2M",
                                     0));
-    op->addTag(TAG_XML_RPC);
+    op->addTag(TAG_RPC);
     handlers.push_back(op);
   }                         
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
-                                   (PREF_XML_RPC_USER,
-                                    TEXT_XML_RPC_USER));
-    op->addTag(TAG_XML_RPC);
+                                   (PREF_RPC_USER,
+                                    TEXT_RPC_USER));
+    op->addTag(TAG_RPC);
     handlers.push_back(op);
   }
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
-                                   (PREF_XML_RPC_PASSWD,
-                                    TEXT_XML_RPC_PASSWD));
-    op->addTag(TAG_XML_RPC);
+                                   (PREF_RPC_PASSWD,
+                                    TEXT_RPC_PASSWD));
+    op->addTag(TAG_RPC);
+    handlers.push_back(op);
+  }
+  {
+    // TODO Deprecated
+    SharedHandle<OptionHandler> op
+      (new DeprecatedOptionHandler
+       (SharedHandle<OptionHandler>(new BooleanOptionHandler
+                                    (PREF_XML_RPC_LISTEN_ALL,
+                                     TEXT_XML_RPC_LISTEN_ALL,
+                                     NO_DEFAULT_VALUE,
+                                     OptionHandler::OPT_ARG)),
+        PREF_RPC_LISTEN_ALL));
+    op->addTag(TAG_RPC);
+    handlers.push_back(op);
+  }
+  {
+    // TODO Deprecated
+    SharedHandle<OptionHandler> op
+      (new DeprecatedOptionHandler
+       (SharedHandle<OptionHandler>(new NumberOptionHandler
+                                    (PREF_XML_RPC_LISTEN_PORT,
+                                     TEXT_XML_RPC_LISTEN_PORT,
+                                     NO_DEFAULT_VALUE,
+                                     1024, UINT16_MAX)),
+        PREF_RPC_LISTEN_PORT));
+    op->addTag(TAG_RPC);
+    handlers.push_back(op);
+  }
+  {
+    // TODO Deprecated
+     SharedHandle<OptionHandler> op
+       (new DeprecatedOptionHandler
+        (SharedHandle<OptionHandler>(new UnitNumberOptionHandler
+                                     (PREF_XML_RPC_MAX_REQUEST_SIZE,
+                                      TEXT_XML_RPC_MAX_REQUEST_SIZE,
+                                      NO_DEFAULT_VALUE,
+                                      0)),
+         PREF_RPC_MAX_REQUEST_SIZE));
+     op->addTag(TAG_RPC);
+     handlers.push_back(op);
+  }
+  {
+    // TODO Deprecated
+    SharedHandle<OptionHandler> op
+      (new DeprecatedOptionHandler
+       (SharedHandle<OptionHandler>(new DefaultOptionHandler
+                                    (PREF_XML_RPC_USER,
+                                     TEXT_XML_RPC_USER)),
+        PREF_RPC_USER));
+    op->addTag(TAG_RPC);
+    handlers.push_back(op);
+  }
+  {
+    // TODO Deprecated
+    SharedHandle<OptionHandler> op
+      (new DeprecatedOptionHandler
+       (SharedHandle<OptionHandler>(new DefaultOptionHandler
+                                    (PREF_XML_RPC_PASSWD,
+                                     TEXT_XML_RPC_PASSWD)),
+        PREF_RPC_PASSWD));
+    op->addTag(TAG_RPC);
     handlers.push_back(op);
   }                         
-#endif // ENABLE_XML_RPC
   // HTTP/FTP options
   {
     SharedHandle<OptionHandler> op(new NumberOptionHandler
@@ -689,6 +769,16 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new NumberOptionHandler
+                                   (PREF_RETRY_WAIT,
+                                    TEXT_RETRY_WAIT,
+                                    "0",
+                                    0, 600));
+    op->addTag(TAG_FTP);
+    op->addTag(TAG_HTTP);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_REUSE_URI,
@@ -1673,7 +1763,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
       TAG_COOKIE,
       TAG_HOOK,
       TAG_FILE,
-      TAG_XML_RPC,
+      TAG_RPC,
       TAG_EXPERIMENTAL,
       TAG_HELP,
       TAG_ALL
