@@ -73,11 +73,11 @@
 # include "bittorrent_helper.h"
 #endif // ENABLE_BITTORRENT
 #ifdef ENABLE_METALINK
-# include "MetalinkHelper.h"
+# include "metalink_helper.h"
 # include "MetalinkEntry.h"
 #endif // ENABLE_METALINK
 #ifdef ENABLE_MESSAGE_DIGEST
-# include "MessageDigestHelper.h"
+# include "message_digest_helper.h"
 #endif // ENABLE_MESSAGE_DIGEST
 
 extern char* optarg;
@@ -127,7 +127,7 @@ void showMetalinkFile
 (const std::string& uri, const SharedHandle<Option>& op)
 {
   std::vector<SharedHandle<MetalinkEntry> > metalinkEntries;
-  MetalinkHelper::parseAndQuery(metalinkEntries, uri, op.get());
+  metalink::parseAndQuery(metalinkEntries, uri, op.get());
   std::vector<SharedHandle<FileEntry> > fileEntries;
   MetalinkEntry::toFileEntry(fileEntries, metalinkEntries);
   util::toStream(fileEntries.begin(), fileEntries.end(), std::cout);
@@ -196,7 +196,7 @@ error_code::Value main(int argc, char* argv[])
   A2_LOG_INFO(MSG_LOGGING_STARTED);
 
 #ifdef ENABLE_MESSAGE_DIGEST
-  MessageDigestHelper::staticSHA1DigestInit();
+  message_digest::staticSHA1DigestInit();
 #endif // ENABLE_MESSAGE_DIGEST
 
   if(op->getAsBool(PREF_DISABLE_IPV6)) {
@@ -254,19 +254,15 @@ error_code::Value main(int argc, char* argv[])
       }
 
   // Remove option values which is only valid for URIs specified in
-  // command-line. If they are left, because op is used as a
-  // template for new RequestGroup(such as created in XML-RPC
-  // command), they causes unintentional effect.
+  // command-line. If they are left, because op is used as a template
+  // for new RequestGroup(such as created in RPC command), they causes
+  // unintentional effect.
   op->remove(PREF_OUT);
   op->remove(PREF_FORCE_SEQUENTIAL);
   op->remove(PREF_INPUT_FILE);
   op->remove(PREF_INDEX_OUT);
   op->remove(PREF_SELECT_FILE);
-  if(
-#ifdef ENABLE_XML_RPC
-     !op->getAsBool(PREF_ENABLE_XML_RPC) &&
-#endif // ENABLE_XML_RPC
-     requestGroups.empty()) {
+  if(!op->getAsBool(PREF_ENABLE_RPC) && requestGroups.empty()) {
     std::cout << MSG_NO_FILES_TO_DOWNLOAD << std::endl;
   } else {
     exitStatus = MultiUrlRequestInfo(requestGroups, op, getStatCalc(op),
