@@ -13,12 +13,12 @@
 #include "MetalinkResource.h"
 #include "MetalinkMetaurl.h"
 #ifdef ENABLE_MESSAGE_DIGEST
-# include "messageDigest.h"
+# include "MessageDigest.h"
 # include "ChunkChecksum.h"
 # include "Checksum.h"
 #endif // ENABLE_MESSAGE_DIGEST
 #include "Signature.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "RecoverableException.h"
 
 namespace aria2 {
@@ -82,24 +82,23 @@ CPPUNIT_TEST_SUITE_REGISTRATION( MetalinkProcessorTest );
 void MetalinkProcessorTest::testParseFileV4()
 {
   MetalinkProcessor proc;
-  SharedHandle<Metalinker> m = proc.parseFile("metalink4.xml");
+  SharedHandle<Metalinker> m = proc.parseFile(A2_TEST_DIR"/metalink4.xml");
   SharedHandle<MetalinkEntry> e;
   SharedHandle<MetalinkResource> r;
   SharedHandle<MetalinkMetaurl> mu;
-  CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
-  e = m->entries[0];
+  CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
+  e = m->getEntries()[0];
   CPPUNIT_ASSERT_EQUAL(std::string("example.ext"), e->getPath());
   CPPUNIT_ASSERT_EQUAL((uint64_t)786430LL, e->getLength());
   CPPUNIT_ASSERT_EQUAL(-1, e->maxConnections);
 #ifdef ENABLE_MESSAGE_DIGEST
   CPPUNIT_ASSERT_EQUAL(std::string("0beec7b5ea3f0fdbc95d0dd47f3c5bc275da8a33"),
 		       e->checksum->getMessageDigest());
-  CPPUNIT_ASSERT(!e->checksum.isNull());
-  CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, e->checksum->getAlgo());
-  CPPUNIT_ASSERT(!e->chunkChecksum.isNull());
-  if(MessageDigestContext::supports(MessageDigestContext::SHA256)) {
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA256,
-                         e->chunkChecksum->getAlgo());
+  CPPUNIT_ASSERT(e->checksum);
+  CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), e->checksum->getAlgo());
+  CPPUNIT_ASSERT(e->chunkChecksum);
+  if(MessageDigest::supports("sha-256")) {
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-256"), e->chunkChecksum->getAlgo());
     CPPUNIT_ASSERT_EQUAL((size_t)262144, e->chunkChecksum->getChecksumLength());
     CPPUNIT_ASSERT_EQUAL((size_t)3, e->chunkChecksum->countChecksum());
     CPPUNIT_ASSERT_EQUAL(std::string("0245178074fd042e19b7c3885b360fc21064b30e73f5626c7e3b005d048069c5"),
@@ -109,8 +108,7 @@ void MetalinkProcessorTest::testParseFileV4()
     CPPUNIT_ASSERT_EQUAL(std::string("37290d74ac4d186e3a8e5785d259d2ec04fac91ae28092e7620ec8bc99e830aa"),
                          e->chunkChecksum->getChecksum(2));
   } else {
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
-                         e->chunkChecksum->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), e->chunkChecksum->getAlgo());
     CPPUNIT_ASSERT_EQUAL((size_t)262144, e->chunkChecksum->getChecksumLength());
     CPPUNIT_ASSERT_EQUAL((size_t)3, e->chunkChecksum->countChecksum());
     CPPUNIT_ASSERT_EQUAL
@@ -124,7 +122,7 @@ void MetalinkProcessorTest::testParseFileV4()
        e->chunkChecksum->getChecksum(2));    
   }
 #endif // ENABLE_MESSAGE_DIGEST
-  CPPUNIT_ASSERT(!e->getSignature().isNull());
+  CPPUNIT_ASSERT(e->getSignature());
   CPPUNIT_ASSERT_EQUAL(std::string("application/pgp-signature"),
                        e->getSignature()->getType());
   CPPUNIT_ASSERT_EQUAL(std::string("a signature"),
@@ -164,12 +162,12 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "<url>http://example.org</url>"
       "</file>"
       "</metalink>";
-    dw->setString(StringFormat(tmpl, "foo").str());
+    dw->setString(fmt(tmpl, "foo"));
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     // empty name
-    dw->setString(StringFormat(tmpl, "").str());
+    dw->setString(fmt(tmpl, ""));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
@@ -178,7 +176,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
     }
 
     // dir traversing
-    dw->setString(StringFormat(tmpl, "../doughnuts").str());
+    dw->setString(fmt(tmpl, "../doughnuts"));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
@@ -194,7 +192,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "<url priority=\"%s\">http://example.org</url>"
       "</file>"
       "</metalink>";
-    dw->setString(StringFormat(tmpl, "0").str());
+    dw->setString(fmt(tmpl, "0"));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
@@ -202,26 +200,26 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       // success
     }
 
-    dw->setString(StringFormat(tmpl, "1").str());
+    dw->setString(fmt(tmpl, "1"));
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(StringFormat(tmpl, "100").str());
+    dw->setString(fmt(tmpl, "100"));
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(StringFormat(tmpl, "999999").str());
+    dw->setString(fmt(tmpl, "999999"));
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(StringFormat(tmpl, "1000000").str());
+    dw->setString(fmt(tmpl, "1000000"));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
     }
-    dw->setString(StringFormat(tmpl, "A").str());
+    dw->setString(fmt(tmpl, "A"));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
@@ -236,7 +234,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "<metaurl priority=\"%s\" mediatype=\"torrent\">http://example.org</metaurl>"
       "</file>"
       "</metalink>";
-    dw->setString(StringFormat(tmpl, "0").str());
+    dw->setString(fmt(tmpl, "0"));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
@@ -244,26 +242,26 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       // success
     }
 
-    dw->setString(StringFormat(tmpl, "1").str());
+    dw->setString(fmt(tmpl, "1"));
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(StringFormat(tmpl, "100").str());
+    dw->setString(fmt(tmpl, "100"));
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(StringFormat(tmpl, "999999").str());
+    dw->setString(fmt(tmpl, "999999"));
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
-    dw->setString(StringFormat(tmpl, "1000000").str());
+    dw->setString(fmt(tmpl, "1000000"));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {
       // success
     }
-    dw->setString(StringFormat(tmpl, "A").str());
+    dw->setString(fmt(tmpl, "A"));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
@@ -294,12 +292,12 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(StringFormat(tmpl, "torrent").str());
+    dw->setString(fmt(tmpl, "torrent"));
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     // empty mediatype
-    dw->setString(StringFormat(tmpl, "").str());
+    dw->setString(fmt(tmpl, ""));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
@@ -317,12 +315,12 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(StringFormat(tmpl, "foo").str());
+    dw->setString(fmt(tmpl, "foo"));
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     // dir traversing
-    dw->setString(StringFormat(tmpl, "../doughnuts").str());
+    dw->setString(fmt(tmpl, "../doughnuts"));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
@@ -330,7 +328,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       // success
     }
     // empty name
-    dw->setString(StringFormat(tmpl, "").str());
+    dw->setString(fmt(tmpl, ""));
     try {
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
@@ -368,17 +366,17 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(StringFormat(tmpl, "262144").str());
+    dw->setString(fmt(tmpl, "262144"));
     m = proc.parseFromBinaryStream(dw);
     // empty
     try {
-      dw->setString(StringFormat(tmpl, "").str());
+      dw->setString(fmt(tmpl, ""));
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
     // not a number
     try {
-      dw->setString(StringFormat(tmpl, "A").str());
+      dw->setString(fmt(tmpl, "A"));
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
@@ -412,11 +410,11 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(StringFormat(tmpl, "sha-1").str());
+    dw->setString(fmt(tmpl, "sha-1"));
     m = proc.parseFromBinaryStream(dw);
     // empty
     try {
-      dw->setString(StringFormat(tmpl, "").str());
+      dw->setString(fmt(tmpl, ""));
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
@@ -446,11 +444,11 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(StringFormat(tmpl, "sha-1").str());
+    dw->setString(fmt(tmpl, "sha-1"));
     m = proc.parseFromBinaryStream(dw);
     // empty
     try {
-      dw->setString(StringFormat(tmpl, "").str());
+      dw->setString(fmt(tmpl, ""));
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
@@ -481,11 +479,11 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</file>"
       "</metalink>";
 
-    dw->setString(StringFormat(tmpl, "application/pgp-signature").str());
+    dw->setString(fmt(tmpl, "application/pgp-signature"));
     m = proc.parseFromBinaryStream(dw);
     // empty
     try {
-      dw->setString(StringFormat(tmpl, "").str());
+      dw->setString(fmt(tmpl, ""));
       m = proc.parseFromBinaryStream(dw);
       CPPUNIT_FAIL("exception must be thrown.");
     } catch(RecoverableException& e) {}
@@ -496,10 +494,10 @@ void MetalinkProcessorTest::testParseFile()
 {
   MetalinkProcessor proc;
   try {
-    SharedHandle<Metalinker> metalinker = proc.parseFile("test.xml");
+    SharedHandle<Metalinker> metalinker = proc.parseFile(A2_TEST_DIR"/test.xml");
 
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      metalinker->entries.begin();
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      metalinker->getEntries().begin();
 
     SharedHandle<MetalinkEntry> entry1 = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), entry1->getPath());
@@ -511,10 +509,9 @@ void MetalinkProcessorTest::testParseFile()
 #ifdef ENABLE_MESSAGE_DIGEST
     CPPUNIT_ASSERT_EQUAL(std::string("a96cf3f0266b91d87d5124cf94326422800b627d"),
                          entry1->checksum->getMessageDigest());
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
-                         entry1->checksum->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), entry1->checksum->getAlgo());
 #endif // ENABLE_MESSAGE_DIGEST
-    CPPUNIT_ASSERT(!entry1->getSignature().isNull());
+    CPPUNIT_ASSERT(entry1->getSignature());
     CPPUNIT_ASSERT_EQUAL(std::string("pgp"), entry1->getSignature()->getType());
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2.sig"),
                          entry1->getSignature()->getFile());
@@ -567,11 +564,10 @@ void MetalinkProcessorTest::testParseFile()
                          entry2->chunkChecksum->getChecksum(0));
     CPPUNIT_ASSERT_EQUAL(std::string("fecf8bc9a1647505fe16746f94e97a477597dbf3"),
                          entry2->chunkChecksum->getChecksum(1));
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
-                         entry2->checksum->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), entry2->checksum->getAlgo());
 #endif // ENABLE_MESSAGE_DIGEST
     // See that signature is null
-    CPPUNIT_ASSERT(entry2->getSignature().isNull());
+    CPPUNIT_ASSERT(!entry2->getSignature());
 
     entryItr++;
 
@@ -579,8 +575,8 @@ void MetalinkProcessorTest::testParseFile()
     SharedHandle<MetalinkEntry> entry3 = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("NoVerificationHash"), entry3->getPath());
 #ifdef ENABLE_MESSAGE_DIGEST
-    CPPUNIT_ASSERT(entry3->checksum.isNull());
-    CPPUNIT_ASSERT(entry3->chunkChecksum.isNull());
+    CPPUNIT_ASSERT(!entry3->checksum);
+    CPPUNIT_ASSERT(!entry3->chunkChecksum);
 #endif // ENABLE_MESSAGE_DIGEST
 
     entryItr++;
@@ -589,12 +585,10 @@ void MetalinkProcessorTest::testParseFile()
     SharedHandle<MetalinkEntry> entry4 = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("UnsupportedVerificationHashTypeIncluded"), entry4->getPath());
 #ifdef ENABLE_MESSAGE_DIGEST
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
-                         entry4->checksum->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), entry4->checksum->getAlgo());
     CPPUNIT_ASSERT_EQUAL(std::string("4c255b0ed130f5ea880f0aa061c3da0487e251cc"),
                          entry4->checksum->getMessageDigest());
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
-                         entry4->chunkChecksum->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"),entry4->chunkChecksum->getAlgo());
 #endif // ENABLE_MESSAGE_DIGEST
 
 
@@ -607,25 +601,26 @@ void MetalinkProcessorTest::testParseFile_dirtraversal()
 {
   MetalinkProcessor proc;
   SharedHandle<Metalinker> metalinker =
-    proc.parseFile("metalink3-dirtraversal.xml");
-  CPPUNIT_ASSERT_EQUAL((size_t)1, metalinker->entries.size());
-  SharedHandle<MetalinkEntry> e = metalinker->entries[0];
+    proc.parseFile(A2_TEST_DIR"/metalink3-dirtraversal.xml");
+  CPPUNIT_ASSERT_EQUAL((size_t)1, metalinker->getEntries().size());
+  SharedHandle<MetalinkEntry> e = metalinker->getEntries()[0];
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.3.tar.bz2"), e->getPath());
-  CPPUNIT_ASSERT(!e->getSignature().isNull());
+  CPPUNIT_ASSERT(e->getSignature());
   CPPUNIT_ASSERT_EQUAL(std::string(""), e->getSignature()->getFile());
 }
 
 void MetalinkProcessorTest::testParseFromBinaryStream()
 {
   MetalinkProcessor proc;
-  DefaultDiskWriterHandle dw(new DefaultDiskWriter("test.xml"));
+  DefaultDiskWriterHandle dw(new DefaultDiskWriter(A2_TEST_DIR"/test.xml"));
+  dw->enableReadOnly();
   dw->openExistingFile();
   
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
 
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      m->entries.begin();
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      m->getEntries().begin();
     SharedHandle<MetalinkEntry> entry1 = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), entry1->getPath());
   } catch(Exception& e) {
@@ -676,10 +671,10 @@ void MetalinkProcessorTest::testBadSizeV4()
      "</file>"
     "</metalink>";
 
-  dw->setString(StringFormat(tmpl, "9223372036854775807").str());
+  dw->setString(fmt(tmpl, "9223372036854775807"));
   m = proc.parseFromBinaryStream(dw);
 
-  dw->setString(StringFormat(tmpl, "-1").str());
+  dw->setString(fmt(tmpl, "-1"));
   try {
     m = proc.parseFromBinaryStream(dw);
     CPPUNIT_FAIL("exception must be thrown.");
@@ -704,8 +699,8 @@ void MetalinkProcessorTest::testBadSize()
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
 
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      m->entries.begin();
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      m->getEntries().begin();
     SharedHandle<MetalinkEntry> e = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), e->getPath());
     CPPUNIT_ASSERT_EQUAL((uint64_t)0ULL, e->getLength());
@@ -737,8 +732,8 @@ void MetalinkProcessorTest::testBadMaxConn()
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
 
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      m->entries.begin();
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      m->getEntries().begin();
     SharedHandle<MetalinkEntry> e = *entryItr;
     CPPUNIT_ASSERT_EQUAL((uint64_t)43743838ULL, e->getLength());
   } catch(Exception& e) {
@@ -769,9 +764,9 @@ void MetalinkProcessorTest::testNoName()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      m->entries.begin();
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      m->getEntries().begin();
     SharedHandle<MetalinkEntry> e = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), e->getPath());
   } catch(Exception& e) {
@@ -800,7 +795,7 @@ void MetalinkProcessorTest::testBadURLPrefs()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<MetalinkResource> r = e->resources[0];
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::TYPE_FTP, r->type);
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::getLowestPriority(), r->priority);
@@ -833,7 +828,7 @@ void MetalinkProcessorTest::testBadURLMaxConn()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<MetalinkResource> r = e->resources[0];
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::TYPE_FTP, r->type);
     CPPUNIT_ASSERT_EQUAL(1, r->priority);
@@ -867,7 +862,7 @@ void MetalinkProcessorTest::testUnsupportedType()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     CPPUNIT_ASSERT_EQUAL((size_t)3, e->resources.size());
     SharedHandle<MetalinkResource> r1 = e->resources[0];
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::TYPE_FTP, r1->type);
@@ -900,10 +895,10 @@ void MetalinkProcessorTest::testMultiplePieces()
   try {
     // aria2 prefers sha1
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
  
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, c->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c->getAlgo());
     CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getChecksumLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
@@ -933,12 +928,12 @@ void MetalinkProcessorTest::testBadPieceNo()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
 
-    CPPUNIT_ASSERT(!c.isNull());
+    CPPUNIT_ASSERT(c);
     CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getChecksumLength());
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, c->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c->getAlgo());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
@@ -966,12 +961,12 @@ void MetalinkProcessorTest::testBadPieceLength()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
-    CPPUNIT_ASSERT(!c.isNull());
+    CPPUNIT_ASSERT(c);
     CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getChecksumLength());
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, c->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c->getAlgo());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
@@ -999,12 +994,12 @@ void MetalinkProcessorTest::testUnsupportedType_piece()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
  
-    CPPUNIT_ASSERT(!c.isNull());
+    CPPUNIT_ASSERT(c);
     CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getChecksumLength());
-    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, c->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c->getAlgo());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
@@ -1028,7 +1023,7 @@ void MetalinkProcessorTest::testLargeFileSize()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     CPPUNIT_ASSERT_EQUAL((uint64_t)9223372036854775807ULL, e->getLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
@@ -1052,8 +1047,8 @@ void MetalinkProcessorTest::testXmlPrefixV3()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     CPPUNIT_ASSERT_EQUAL((uint64_t)9223372036854775807ULL, e->getLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
